FunctionCallData

Struct FunctionCallData 

pub struct FunctionCallData {
    pub function: String,
    pub parameters: Option<FunctionCallParametersData>,
}
FunctionCall

  • Describes a single call to a function by optionally providing values to its parameters.
  • ๐Ÿ‘€ See parameter substitution for an example usage

Fields

function: String
  • Name of the function to call.
  • โ— Function with same name must defined in functions property of Collection
parameters: Option<FunctionCallParametersData>
  • Defines key value dictionary for each parameter and its value

  • E.g.

      parameters:
        userDefinedParameterName: parameterValue
        # ...
        appName: Microsoft.WindowsFeedbackHub
  • ๐Ÿ’ก Expressions (templating) can be used as parameter value