ScriptData

Struct ScriptData 

pub struct ScriptData {
    pub name: String,
    pub code: Option<String>,
    pub revert_code: Option<String>,
    pub call: Option<FunctionCallsData>,
    pub docs: Option<DocumentationUrlsData>,
    pub recommend: Option<Recommend>,
}
Script

  • Script represents a single tweak.
  • A script can be of two different types (just like functions):
    1. Inline script; a script with an inline code
      • Must define code property and optionally revertCode but not call
    2. Caller script; a script that calls other functions
      • Must define call property but not code or revertCode
  • ๐Ÿ™ For any new script, please add revertCode and docs values if possible.

Fields

name: String
  • Name of the script
  • โ— Must be unique throughout the Collection
code: Option<String>
  • Batch file commands that will be executed
  • ๐Ÿ’ก If defined, best practice to also define revertCode
  • โ— If not defined call must be defined, do not define if call is defined.
revert_code: Option<String>
  • Code thatโ€™ll undo the change done by code property.
  • E.g. letโ€™s say code sets an environment variable as setx POWERSHELL_TELEMETRY_OPTOUT 1
    • then revertCode should be doing setx POWERSHELL_TELEMETRY_OPTOUT 0
  • โ— Do not define if call is defined.
call: Option<FunctionCallsData>
  • A shared function or sequence of functions to call (called in order)
  • โ— If not defined code must be defined
docs: Option<DocumentationUrlsData>
  • Single documentation URL or list of URLs for those who wants to learn more about the script
  • E.g. https://docs.microsoft.com/en-us/windows-server/
recommend: Option<Recommend>
  • If not defined then the script will not be recommended
  • If defined it can be either
    • standard: Only non-breaking scripts without limiting OS functionality
    • strict: Scripts that can break certain functionality in favor of privacy and security