pub struct ScriptingDefinitionData {
pub language: String,
pub file_extension: Option<String>,
pub start_code: String,
pub end_code: String,
}Expand description
ScriptingDefinition
- Defines global properties for scripting that’s used throughout its parent Collection.
Fields
language: StringName of the Script
file_extension: Option<String>Optional file extension for the said script
start_code: String- Code that’ll be inserted on top of user created script.
- Global variables such as
$homepage,$version,$datecan be used using parameter substitution code syntax such asWelcome to {{ $homepage }}!
end_code: String- Code that’ll be inserted at the end of user created script.
- Global variables such as
$homepage,$version,$datecan be used using parameter substitution code syntax such asWelcome to {{ $homepage }}!